;;; emacs-lisp-intro-nl.el --- ELisp intro manual in NL  -*- lexical-binding:t -*-

;; Copyright (C) 2026  Free Software Foundation, Inc.
;;
;; Author: Matto Fransen <matto@matto.nl>
;; Version: 0

;;; Commentary:

;; This is just a dummy file that holds the package's metadata.

;;; Code:

(provide 'emacs-lisp-intro-nl)
;;; emacs-lisp-intro-nl.el ends here
