;; Generated package description from emacs-lisp-intro-nl.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "emacs-lisp-intro-nl" "0.0.20260401.91353" "ELisp intro manual in NL" 'nil :commit "d6ddf0e111989e94af0ef83421c990bdadaf2391" :url "https://elpa.gnu.org/packages/emacs-lisp-intro-nl.html" :authors '(("Matto Fransen" . "matto@matto.nl")) :maintainer '("Matto Fransen" . "matto@matto.nl"))
